@@ -2227,3 +2227,32 @@ def test_type_num_lines(parse_fortran_file):
     example_type = module.types[0]
     assert example_type.num_lines == 8
     assert example_type.num_lines_all == 8 + 9
+
+
+def test_associate_array(parse_fortran_file):
+    data = """\
+    subroutine test()
+      associate(phi => [1,2], theta => (/ 3, 4 /))
+      end associate
+    end subroutine test"""
+
+    # Just check we can parse ok
+    parse_fortran_file(data)
+
+
+def test_blocks_with_type(parse_fortran_file):
+    data = """\
+    module foo
+    contains
+      subroutine sub1()
+        block
+          type :: t1
+          end type t1
+        end block
+      end subroutine sub1
+    end module foo
+    """
+
+    source = parse_fortran_file(data)
+    module = source.modules[0]
+    assert len(module.subroutines) == 1
